You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by pa...@apache.org on 2007/01/02 17:01:29 UTC

svn commit: r491823 - /myfaces/tomahawk/trunk/core/src/test/java/org/apache/myfaces/test/utils/TestUtils.java

Author: paulsp
Date: Tue Jan  2 08:01:28 2007
New Revision: 491823

URL: http://svn.apache.org/viewvc?view=rev&rev=491823
Log:
Render components, not just encode them.

Modified:
    myfaces/tomahawk/trunk/core/src/test/java/org/apache/myfaces/test/utils/TestUtils.java

Modified: myfaces/tomahawk/trunk/core/src/test/java/org/apache/myfaces/test/utils/TestUtils.java
URL: http://svn.apache.org/viewvc/myfaces/tomahawk/trunk/core/src/test/java/org/apache/myfaces/test/utils/TestUtils.java?view=diff&rev=491823&r1=491822&r2=491823
==============================================================================
--- myfaces/tomahawk/trunk/core/src/test/java/org/apache/myfaces/test/utils/TestUtils.java (original)
+++ myfaces/tomahawk/trunk/core/src/test/java/org/apache/myfaces/test/utils/TestUtils.java Tue Jan  2 08:01:28 2007
@@ -489,7 +489,7 @@
     }
 
     /**
      * Renderered a component and it's children.
      * 
      * @param context Faces Context
      * @param component Component to be rendered.
@@ -503,5 +503,7 @@
         renderer.encodeBegin(context, component);
         renderer.encodeChildren(context, component);
         renderer.encodeEnd(context, component);
+        context.responseComplete();
+        context.renderResponse();
     }
 }
@@ -489,7 +489,7 @@
 
     /**
-     * Renderered a component and it's children.
+     * Renderered a component, including it's children, then complete the reponse.
      * 
      * @param context Faces Context